Distribution list
=================

This page serves as an overview of the various distributions available in the
``metasyn.distribution`` module. Clicking on a distribution will take you to a page with more information, including its parameters.

Categorical Distributions
^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.categorical

.. autosummary::
   :toctree: generated/

   MultinoulliDistribution -- Stores labels and probabilities.


Constant Distributions
^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.constant

.. autosummary::
   :toctree: generated/

   ContinuousConstantDistribution
   DiscreteConstantDistribution
   DateTimeConstantDistribution
   TimeConstantDistribution
   DateConstantDistribution
   StringConstantDistribution

Exponential Distribution
^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.exponential

.. autosummary::
   :toctree: generated/

   ExponentialDistribution


Faker Distributions
^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.faker

.. autosummary::
   :toctree: generated/

   FakerDistribution
   UniqueFakerDistribution

Free Text Distribution
^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.freetext

.. autosummary::
   :toctree: generated/
   
   FreeTextDistribution


NA Distribution
^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.na

.. autosummary::
   :toctree: generated/
   
   NADistribution


Normal Distributions
^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.normal

.. autosummary::
   :toctree: generated/
   
   ContinuousNormalDistribution
   LogNormalDistribution
   ContinuousTruncatedNormalDistribution
   DiscreteNormalDistribution
   DiscreteTruncatedNormalDistribution


Poisson Distribution
^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.poisson

.. autosummary::
   :toctree: generated/
   
   PoissonDistribution


Regex Distributions
^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.regex

.. autosummary::
   :toctree: generated/
   
   RegexDistribution
   UniqueRegexDistribution

Uniform Distributions
^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.uniform

.. autosummary::
   :toctree: generated/
   
   DiscreteUniformDistribution
   ContinuousUniformDistribution
   DateTimeUniformDistribution
   DateUniformDistribution
   TimeUniformDistribution

Unique Key Distribution
^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: metasyn.distribution.uniquekey

.. autosummary::
   :toctree: generated/
   
   UniqueKeyDistribution

